############################
#
# initrd, building the initrd.gz file.
#
# this is a bit special than most other .mk files since it will always 
# build the file, regardeless the exsistence of a initrd.gz file.
#
# The reasons are that we don't know which type of initrd.gz file we have, 
# we do make two of'em here already (IDE and basic) and since the building
# of the images, initrd.gz and add.bz2 are separate from the rest, you never
# really know when to build or not. 
#
# So, this is being on the safe side.
#
##########################


initrd-base: $(INITRD_MASTER)
	-[ -d /tmp/mnt ] && rm -rf /tmp/mnt
	-[ -f /tmp/initrd ] && rm -f /tmp/initrd

	dd if=/dev/zero of=/tmp/initrd count=768 bs=1024
	
	mkfs.minix /tmp/initrd
	mkdir /tmp/mnt
	mount -t minix -o loop /tmp/initrd /tmp/mnt
	cp -a $(INITRD_MASTER)/* /tmp/mnt/.
	cp -a $(SCRIPTS_DIR)/linuxrc /tmp/mnt/.
	cp -a $(SCRIPTS_DIR)/rc.initrd /tmp/mnt/etc/.
	cp -a $(SCRIPTS_DIR)/functions.inc /tmp/mnt/etc/.
	cp -a $(SCRIPTS_DIR)/inittab /tmp/mnt/etc/.
	cp -a $(SCRIPTS_DIR)/inittab.serial /tmp/mnt/etc/.
	
	(cd /tmp/mnt/dev ; \
		mknod -m 600 console c 5 1; \
		mknod -m 600 tty0 c 4 0; \
		mknod -m 600 tty1 c 4 1; \
		mknod -m 660 ram0 b 1 0; \
	);
	sync
	umount /tmp/mnt
	gzip -9 /tmp/initrd
	mv /tmp/initrd.gz $(INITRD_DIR)/initrd.gz


# I wish I didn't have to repeat the whole thing here:
# This has a dependancy of idemods (which could trigger quite alot) but
# idemods.bz2 are the whole point of this.
initrd-ide: $(INITRD_MASTER) $(MODULES_BASE_DIR)/idemods.bz2
	-[ -d /tmp/mnt ] && rm -rf /tmp/mnt
	-[ -f /tmp/initrd ] && rm -f /tmp/initrd

	dd if=/dev/zero of=/tmp/initrd count=1536 bs=1024
	
	mkfs.minix /tmp/initrd
	mkdir /tmp/mnt
	mount -t minix -o loop /tmp/initrd /tmp/mnt
	cp -a $(INITRD_MASTER)/* /tmp/mnt/.
	cp -a $(SCRIPTS_DIR)/linuxrc /tmp/mnt/.
	cp -a $(SCRIPTS_DIR)/rc.initrd /tmp/mnt/etc/.
	cp -a $(SCRIPTS_DIR)/functions.inc /tmp/mnt/etc/.
	cp -a $(SCRIPTS_DIR)/inittab /tmp/mnt/etc/.
	cp -a $(SCRIPTS_DIR)/inittab.serial /tmp/mnt/etc/.

	bzcat $(MODULES_BASE_DIR)/idemods.bz2 | tar -C /tmp/mnt -xvf -

	(cd /tmp/mnt/dev ; \
		mknod -m 600 console c 5 1; \
		mknod -m 600 tty0 c 4 0; \
		mknod -m 600 tty1 c 4 1; \
		mknod -m 660 ram0 b 1 0; \
	);
	sync
	umount /tmp/mnt
	gzip -9 /tmp/initrd
	mv /tmp/initrd.gz $(INITRD_DIR)/initrd.gz


initrd-clean: 
	-rm -f $(INITRD_DIR)/initrd.gz
	-rm -f $(BASE_DIR)/floppy/initrd.gz

initrd-dirclean: 
	-rm -f $(INITRD_DIR)/initrd.gz
	-rm -rf $(INITRD_MASTER)
	
